==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/GeographicShapeSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ShapeDataSourceDescriptionMetadata } from "./ShapeDataSourceDescriptionMetadata";
import { AssigningShapeStyleEventArgsDescriptionMetadata } from "./AssigningShapeStyleEventArgsDescriptionMetadata";
import { AssigningShapeMarkerStyleEventArgsDescriptionMetadata } from "./AssigningShapeMarkerStyleEventArgsDescriptionMetadata";
import { GeographicMapSeriesHostDescriptionMetadata } from "./GeographicMapSeriesHostDescriptionMetadata";
/**
 * @hidden
 */
var GeographicShapeSeriesBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GeographicShapeSeriesBaseDescriptionMetadata, _super);
    function GeographicShapeSeriesBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GeographicShapeSeriesBaseDescriptionMetadata.b = function (a) {
        if (GeographicShapeSeriesBaseDescriptionMetadata.a == null) {
            GeographicShapeSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GeographicShapeSeriesBaseDescriptionMetadata.c(GeographicShapeSeriesBaseDescriptionMetadata.a);
        }
        if (a.j(GeographicShapeSeriesBaseDescriptionMetadata.a)) {
            return;
        }
        a.y(GeographicShapeSeriesBaseDescriptionMetadata.a);
        ShapeDataSourceDescriptionMetadata.d(a);
        AssigningShapeStyleEventArgsDescriptionMetadata.d(a);
        AssigningShapeMarkerStyleEventArgsDescriptionMetadata.d(a);
    };
    GeographicShapeSeriesBaseDescriptionMetadata.c = function (a) {
        GeographicMapSeriesHostDescriptionMetadata.c(a);
        a.item("ShapeMemberPath", "String");
        a.item("IsCustomShapeStyleAllowed", "Boolean");
        a.item("IsCustomShapeMarkerStyleAllowed", "Boolean");
        a.item("ItemSearchMode", "ExportedType:string:ShapeItemSearchMode");
        a.item("ItemSearchMode@names", "Auto;ClosestBoundingBox;ClosestShape;ClosestPointOnClosestShape;None");
        a.item("ItemSearchThreshold", "Number:int");
        a.item("ItemSearchPointsThreshold", "Number:int");
        a.item("ShapefileDataSource", "ExportedType:ShapefileConverter");
        a.item("ShapeFilterResolution", "Number:double");
        a.item("AssigningShapeStyleRef", "EventRef::assigningShapeStyle");
        a.item("AssigningShapeMarkerStyleRef", "EventRef::assigningShapeMarkerStyle");
    };
    GeographicShapeSeriesBaseDescriptionMetadata.d = function (a) {
        GeographicShapeSeriesBaseDescriptionMetadata.b(a);
        a.z("GeographicShapeSeriesBase", GeographicShapeSeriesBaseDescriptionMetadata.a);
    };
    GeographicShapeSeriesBaseDescriptionMetadata.$t = markType(GeographicShapeSeriesBaseDescriptionMetadata, 'GeographicShapeSeriesBaseDescriptionMetadata');
    GeographicShapeSeriesBaseDescriptionMetadata.a = null;
    return GeographicShapeSeriesBaseDescriptionMetadata;
}(Base));
export { GeographicShapeSeriesBaseDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/GeographicShapeSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ShapeDataSourceDescriptionMetadata } from "./ShapeDataSourceDescriptionMetadata";
import { AssigningShapeStyleEventArgsDescriptionMetadata } from "./AssigningShapeStyleEventArgsDescriptionMetadata";
import { AssigningShapeMarkerStyleEventArgsDescriptionMetadata } from "./AssigningShapeMarkerStyleEventArgsDescriptionMetadata";
import { GeographicMapSeriesHostDescriptionMetadata } from "./GeographicMapSeriesHostDescriptionMetadata";
/**
 * @hidden
 */
var GeographicShapeSeriesBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GeographicShapeSeriesBaseDescriptionMetadata, _super);
    function GeographicShapeSeriesBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GeographicShapeSeriesBaseDescriptionMetadata.b = function (a) {
        if (GeographicShapeSeriesBaseDescriptionMetadata.a == null) {
            GeographicShapeSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GeographicShapeSeriesBaseDescriptionMetadata.c(GeographicShapeSeriesBaseDescriptionMetadata.a);
        }
        if (a.k(GeographicShapeSeriesBaseDescriptionMetadata.a)) {
            return;
        }
        a.aa(GeographicShapeSeriesBaseDescriptionMetadata.a);
        ShapeDataSourceDescriptionMetadata.d(a);
        AssigningShapeStyleEventArgsDescriptionMetadata.d(a);
        AssigningShapeMarkerStyleEventArgsDescriptionMetadata.d(a);
    };
    GeographicShapeSeriesBaseDescriptionMetadata.c = function (a) {
        GeographicMapSeriesHostDescriptionMetadata.c(a);
        a.item("ShapeMemberPath", "String");
        a.item("IsCustomShapeStyleAllowed", "Boolean");
        a.item("IsCustomShapeMarkerStyleAllowed", "Boolean");
        a.item("ItemSearchMode", "ExportedType:string:ShapeItemSearchMode");
        a.item("ItemSearchMode@names", "Auto;ClosestBoundingBox;ClosestShape;ClosestPointOnClosestShape;None");
        a.item("ItemSearchThreshold", "Number:int");
        a.item("ItemSearchPointsThreshold", "Number:int");
        a.item("ShapefileDataSource", "ExportedType:ShapefileConverter");
        a.item("ShapeFilterResolution", "Number:double");
        a.item("AssigningShapeStyleRef", "EventRef::assigningShapeStyle");
        a.item("AssigningShapeMarkerStyleRef", "EventRef::assigningShapeMarkerStyle");
    };
    GeographicShapeSeriesBaseDescriptionMetadata.d = function (a) {
        GeographicShapeSeriesBaseDescriptionMetadata.b(a);
        a.ab("GeographicShapeSeriesBase", GeographicShapeSeriesBaseDescriptionMetadata.a);
    };
    GeographicShapeSeriesBaseDescriptionMetadata.$t = markType(GeographicShapeSeriesBaseDescriptionMetadata, 'GeographicShapeSeriesBaseDescriptionMetadata');
    GeographicShapeSeriesBaseDescriptionMetadata.a = null;
    return GeographicShapeSeriesBaseDescriptionMetadata;
}(Base));
export { GeographicShapeSeriesBaseDescriptionMetadata };
